package domain;

import java.util.StringTokenizer;

public class TimeV1 implements Time {
	private int h;
	private int m;
	public TimeV1() {
		super();
		h = 12;
		m = 0;
	}
	public TimeV1(int hour, int minute) throws BadHourException, BadMinuteException {
		super();
		if (hour < 0 || hour >= HOURS_PER_DAY) throw new BadHourException(hour);
		h = hour;
		if (minute < 0 || minute >= MINUTES_PER_HOUR) throw new BadMinuteException(minute);
		m = minute;
	}
	public TimeV1(String s) throws BadHourException, BadMinuteException, BadFormatException {
		super();
		if (!s.matches("^[0-9]{1,2}:[0-9]{2}$")) throw new BadFormatException(s);
		StringTokenizer st = new StringTokenizer(s, ":");
		h = Integer.parseInt(st.nextToken());
		if (h < 0 || h >= HOURS_PER_DAY) throw new BadHourException(h);
		m = Integer.parseInt(st.nextToken());
		if (m < 0 || m >= MINUTES_PER_HOUR) throw new BadMinuteException(m);
	}
	@Override
	public int hour() {
		return h;
	}
	@Override
	public int minute() {
		return m;
	}
	@Override
	public void oneMinuteLater() {
		m = (m + 1) % MINUTES_PER_HOUR;
		if (m == 0) oneHourLater();
	}
	@Override
	public void oneHourLater() {
		h = (h + 1) % HOURS_PER_DAY;
	}
	@Override
	public void oneHourEarlier() {
		h--;
		if (h < 0) h = HOURS_PER_DAY - 1;
	}
	@Override
	public void oneMinuteEarlier() {
		m--;
		if (m < 0 ) {
			m = MINUTES_PER_HOUR - 1;
			oneHourEarlier();
		}
	}
	@Override
	public String toString() {
		String s = "V1 " + ((h < 10) ? "0" : "");
		s += h;
		s += ":";
		s += (m < 10) ? "0" : "";
		s += m;
		return s;
	}
}
