package domain;

import java.util.StringTokenizer;

public class TimeV2 implements Time {
	private static int MINUTES_PER_DAY = 1440;
	private int m; /* minutes coules depuis minuit */
	public TimeV2() {
		m = MINUTES_PER_DAY / 2;
	}
	public TimeV2(int hour, int minute) throws BadHourException, BadMinuteException {
		if (hour < 0 || hour >= HOURS_PER_DAY) throw new BadHourException(hour);
		if (minute < 0 || minute >= MINUTES_PER_HOUR) throw new BadMinuteException(minute);
		m = (hour * MINUTES_PER_HOUR) + minute;
	}
	public TimeV2(String s) throws BadHourException, BadMinuteException, BadFormatException {
		if (!s.matches("^[0-9]{1,2}:[0-9]{2}$")) throw new BadFormatException(s);
		StringTokenizer st = new StringTokenizer(s, ":");
		int h, m;
		h = Integer.parseInt(st.nextToken());
		if (h < 0 || h >= HOURS_PER_DAY) throw new BadHourException(h);
		m = Integer.parseInt(st.nextToken());
		if (m < 0 || m >= MINUTES_PER_HOUR) throw new BadMinuteException(m);
		this.m = (h * MINUTES_PER_HOUR) + m;
	}
	public int hour() {
		return m / MINUTES_PER_HOUR;
	}
	public int minute() {
		return m % MINUTES_PER_HOUR;
	}
	public void oneMinuteLater() {
		m = (m + 1) % MINUTES_PER_DAY;
	}
	public void oneHourLater() {
		m = (m + MINUTES_PER_HOUR) % MINUTES_PER_DAY;
	}
	public void oneHourEarlier() {
		m -= MINUTES_PER_HOUR;
		if (m < 0) m += MINUTES_PER_DAY;
	}
	public void oneMinuteEarlier() {
		m--;
		if (m < 0) m += MINUTES_PER_DAY;
	}
	public String toString() {
		int h = hour();
		String s = "V2 " + ((h < 10) ? "0" : "");
		s += h;
		s += ":";
		int m = minute();
		s += (m < 10) ? "0" : "";
		s += m;
		return s;
	}
}
