package test;

import static org.junit.jupiter.api.Assertions.*;
import org.junit.jupiter.api.Test;

import domain.BadFormatException;
import domain.BadHourException;
import domain.BadMinuteException;
import domain.Time;
import domain.TimeV1;

class TimeTest {
	@Test
	void contructorTest() throws BadHourException, BadMinuteException, BadFormatException {
		Time t = new TimeV1();
		assertEquals(12, t.hour());
		assertEquals(0, t.minute());
		t = new TimeV1(13, 15);
		assertEquals(13, t.hour());
		assertEquals(15, t.minute());
		t = new TimeV1("08:20");
		assertEquals(8, t.hour());
		assertEquals(20, t.minute());
	}
	@Test
	void contructorExceptionTest() {
		Exception e;
		e = assertThrows(BadFormatException.class, () -> new TimeV1("8h20"));
		assertEquals("bad format for string '8h20' for a new time", e.getMessage());
		e = assertThrows(BadHourException.class, () -> new TimeV1(24, 0));
		assertEquals("bad value for hour (24) for a new time", e.getMessage());
		e = assertThrows(BadMinuteException.class, () -> new TimeV1(12, 60));
		assertEquals("bad value for minute (60) for a new time", e.getMessage());
		e = assertThrows(BadHourException.class, () -> new TimeV1(-1, 0));
		assertEquals("bad value for hour (-1) for a new time", e.getMessage());
		e = assertThrows(BadMinuteException.class, () -> new TimeV1(20, -1));
		assertEquals("bad value for minute (-1) for a new time", e.getMessage());
	}
	@Test
	void oneMinuteLaterTest() throws BadHourException, BadMinuteException {
		Time t = new TimeV1(15, 20);
		t.oneMinuteLater();
		assertEquals(15, t.hour());
		assertEquals(21, t.minute());
		t = new TimeV1(15, 59);
		t.oneMinuteLater();
		assertEquals(16, t.hour());
		assertEquals(0, t.minute());
		t = new TimeV1(23, 59);
		t.oneMinuteLater();
		assertEquals(0, t.hour());
		assertEquals(0, t.minute());
	}
	@Test
	void oneHourLaterTest() throws BadHourException, BadMinuteException {
		Time t = new TimeV1(15, 20);
		t.oneHourLater();
		assertEquals(16, t.hour());
		assertEquals(20, t.minute());
		t = new TimeV1(23, 15);
		t.oneHourLater();
		assertEquals(0, t.hour());
		assertEquals(15, t.minute());
	}
	@Test
	void oneHourEarlierTest() throws BadHourException, BadMinuteException {
		Time t = new TimeV1(10, 8);
		t.oneHourEarlier();
		assertEquals(9, t.hour());
		assertEquals(8, t.minute());
		t = new TimeV1(0, 15);
		t.oneHourEarlier();
		assertEquals(23, t.hour());
		assertEquals(15, t.minute());
	}
	@Test
	void oneMinuteEarlierTest() throws BadHourException, BadMinuteException {
		Time t = new TimeV1(15, 20);
		t.oneMinuteEarlier();
		assertEquals(15, t.hour());
		assertEquals(19, t.minute());
		t = new TimeV1(15, 0);
		t.oneMinuteEarlier();
		assertEquals(14, t.hour());
		assertEquals(59, t.minute());
		t = new TimeV1(0, 0);
		t.oneMinuteEarlier();
		assertEquals(23, t.hour());
		assertEquals(59, t.minute());
	}
	@Test
	void toStringTest() throws BadHourException, BadMinuteException {
		Time t = new TimeV1(10, 27);
		assertEquals("V1 10:27", t.toString());
		t = new TimeV1(8, 3);
		assertEquals("V1 08:03", t.toString());
	}
}
